@@ -1,8 +1,8 @@
 MOCK_LEGACY_TX_PARAMS = {
-    "from_": "0x62468FD916bF27A3b76d3de2e5280e53078e13E1",
+    "from": "0x62468FD916bF27A3b76d3de2e5280e53078e13E1",
     "to": "0x62468FD916bF27A3b76d3de2e5280e53078e13E1",
     "value": "100000000000000000",
-    "data": "OxSomeData",
+    "data": "0x97c5ed1e",
     "gas": "21000",
     "nonce": 42,
     "type": 1,
